#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ROR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ROR_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/scalar/ror.hpp>

#endif
